# Copyright (C) 2015, 2016, 2017 Cumulus Networks, Inc. All rights reserved
#
# This software is subject to the Cumulus Networks End User License Agreement available
# at the following locations:
#
# Internet: https://cumulusnetworks.com/downloads/eula/latest/view/
# Cumulus Linux systems: /usr/share/cumulus/EULA.txt

from restapi import settings
from setuptools import setup
import os
#import queue  # TODO - Python3
import Queue
import re


os.environ['ENV'] = 'prod'


def _copy_dir(dir_path):
    base_dir = os.path.join(os.path.dirname(__file__), dir_path)
#    my_queue = queue.Queue()  # TODO - Python3
    my_queue = Queue.Queue()
    my_queue.put(base_dir)
    while not my_queue.empty():
        root_dir = my_queue.get()
        for dirpath, dirnames, files in os.walk(root_dir):
            for dirname in dirnames:
                my_queue.put(os.path.join(dirpath, dirname))
                filelist = [os.path.join(dirpath, filename) for filename in files]
                yield re.sub('.*{0}/?'.format(dir_path), '', dirpath), filelist

_data_files = [ (src, files) for src, files in _copy_dir('swagger-ui') ]
_data_files.append(('apps/evo/swagger/', ['restapi/apps/evo/swagger/evo.json']))

with open(os.path.join(settings.BASE_DIR, 'requirements/common.txt')) as f:
    _requirements_lines = [ line.strip() for line in f ]

# Note that "filter" returns an iterator, not a list, in Python3.  Passing
# None to "filter" as the function parameter removes elements for which
# bool(element) is False.
_install_requires = list(filter(None, _requirements_lines))

# The constant settings.__version__ is used in multiple places, but the build group
# needs to use a literal with the setup function (below).  Perform the following
# assertion check to make sure the literal doesn't diverge from the value of the
# constant.
#assert settings.__version__ == '0.0.2'

setup(name='python-cumulus-restapi',
#      version=settings.__version__,
      version='0.0.2',                # When this changes, change the above assert!
      description="ReST API",
      author='Cumulus Networks',
      author_email='dev-support@cumulusnetworks.com',
      url='cumulusnetworks.com',
      scripts=[
          'bin/wsgi.py',
          'bin/restserver'
      ],
      setup_requires=[
          'setuptools>=0.6cc1'
      ],
      # TODO - Figure out how not to have to enter packages manually.
      #packages=find_packages(exclude=['tests']),  This doesn't work. :(
      packages=[
          'restapi',
          'restapi.apps', 'restapi.apps.evo', 'restapi.apps.ml2',
              'restapi.apps.nclu', 'restapi.apps.openswitch',
          'restapi.cmd',
          'restapi.middleware',
          'restapi.settings',
          'restapi.utils',
      ],
      include_package_data=True,
      zip_safe=False,
      install_requires=_install_requires,
      data_files=[(os.path.join(settings.STATIC_FILES, dirpath), file_list) for dirpath, file_list in _data_files]
    )

