# Copyright (C) 2015, 2016, 2017 Cumulus Networks, Inc. All rights reserved
#
# This software is subject to the Cumulus Networks End User License Agreement available
# at the following locations:
#
# Internet: https://cumulusnetworks.com/downloads/eula/latest/view/
# Cumulus Linux systems: /usr/share/cumulus/EULA.txt

import json
import os.path

from fabric.api import env, sudo
import fabric.contrib.files
from falcon.testing import TestBase
from restapi.urls import reverse


class MyTestBase(TestBase):

    _TEMPLATE_DIR = os.path.join(os.path.dirname(__file__), 'templates')

    _INTERFACES_FILE = '/etc/network/interfaces'

    _INTERFACES_DIR = '/etc/network/interfaces.d'

    _CONFIG_FILE = os.path.join(_INTERFACES_DIR, 'tcconfig')

    def __init__(self, *args, **kwargs):
        self._url = None
        self._response = None
        self._response_json = None
        self._config = None
        env.user = 'sameer'
        env.host_string = 'localhost:2501'
        super(MyTestBase, self).__init__(*args, **kwargs)

    @classmethod
    def setUpClass(cls):
        if not fabric.contrib.files.contains(
                cls._INTERFACES_FILE, 'source %s/*' % cls._INTERFACES_DIR):
            fabric.contrib.files.append(cls._INTERFACES_FILE,
                                        'source %s/*' % cls._INTERFACES_DIR,
                                        use_sudo=True)
        cls.reload_networking()

    @classmethod
    def tearDownClass(cls):
        if fabric.contrib.files.exists(cls._CONFIG_FILE):
            sudo('rm -f %s' % cls._CONFIG_FILE)
        if fabric.contrib.files.contains(cls._INTERFACES_FILE,
                                         'source %s/*' % cls._INTERFACES_DIR):
            fabric.contrib.files.sed(cls._INTERFACES_FILE,
                                     'source %s/\*' % cls._INTERFACES_DIR,
                                     '', use_sudo=True)
        cls.reload_networking()

    def before(self):
        self._response = None
        self._response_json = None
        print('\n*** Executing %s ***' % self._testMethodName)

    def after(self):
        if self._response_json is not None:
            print('Response body: %s' % json.dumps(self._response_json,
                                                   sort_keys=True,
                                                   indent=4,
                                                   separators=(',', ': ')))
        elif self._response is not None:
            print('Response body: %s' % self._response.text)
        print('Response status code: %s' % self._response.status_code)
        print('*** Finished %s ***' % self._url)

    @staticmethod
    def reversed(*args, **kwargs):
        return 'http://%s/%s' % ('127.0.0.1:8000', reverse(*args, **kwargs))

    @classmethod
    def upload_template(cls, filename, context=None):
        return fabric.contrib.files.upload_template(filename,
                                                    cls._CONFIG_FILE,
                                                    context=context,
                                                    template_dir=
                                                    cls._TEMPLATE_DIR,
                                                    use_jinja=True,
                                                    backup=False,
                                                    use_sudo=True)

    @staticmethod
    def reload_networking():
        sudo('service networking reload')
