# pylint: skip-file
# Copyright (C) 2015, 2016, 2017 Cumulus Networks, Inc. All rights reserved
#
# This software is subject to the Cumulus Networks End User License Agreement available
# at the following locations:
#
# Internet: https://cumulusnetworks.com/downloads/eula/latest/view/
# Cumulus Linux systems: /usr/share/cumulus/EULA.txt

import json

import requests

from restapi.utils.misc import sanitize
from tests.test_base import MyTestBase


class BridgeTests(MyTestBase):

    __BRIDGE = 'br0'
    __INTERFACE = 'swp3'

    def __init__(self, *args, **kwargs):
        super(BridgeTests, self).__init__(*args, **kwargs)

    @classmethod
    def setUpClass(cls):
        cls.upload_template('bridge_config.tmpl',
                            context={
                                'dev': cls.__INTERFACE,
                                'bridge': cls.__BRIDGE
                                }
                            )
        super(BridgeTests, cls).setUpClass()

    @classmethod
    def tearDownClass(cls):
        super(BridgeTests, cls).tearDownClass()

    def test_bridge_fdb(self):
        self._url = self.reversed('bridgeFdbShow', self.__BRIDGE)
        self._response = requests.get(self._url)
        self.assertEquals(self._response.status_code, 200)
        self._response_json = json.loads(self._response.text)
        self.assertEquals(sanitize(self._response_json['output']),
                          u'08:00:27:9b:83:52 dev %s vlan 0 master %s '
                          u'permanent' % (self.__INTERFACE, self.__BRIDGE))

    def test_bridge(self):
        self._url = self.reversed('bridgeFdbCtl', self.__BRIDGE)
        self._response = requests.get(self._url)
        self.assertEquals(self._response.status_code, 200)
        self._response_json = json.loads(self._response.text)
        self.assertEquals(sanitize(self._response_json['output']),
                          u'bridge name bridge id STP enabled interfaces '
                          u'%s 8000.0800279b8352 no %s' % (
                              self.__BRIDGE, self.__INTERFACE,
                          ))


