# pylint: skip-file
# Copyright (C) 2015, 2016, 2017 Cumulus Networks, Inc. All rights reserved
#
# This software is subject to the Cumulus Networks End User License Agreement available
# at the following locations:
#
# Internet: https://cumulusnetworks.com/downloads/eula/latest/view/
# Cumulus Linux systems: /usr/share/cumulus/EULA.txt

import json

import requests

from restapi.apps.evo.interface import IfCommand, IpLink
from tests.test_base import MyTestBase


class IntfTests(MyTestBase):

    __BOND = 'bond0'

    __INTERFACE = 'swp3'

    def __init__(self, *args, **kwargs):
        super(IntfTests, self).__init__(*args, **kwargs)

    @classmethod
    def setUpClass(cls):
        cls.upload_template('intf_config.tmpl',
                            context={
                                'dev': cls.__INTERFACE,
                                'bond': cls.__BOND
                                }
                            )
        super(IntfTests, cls).setUpClass()

    @classmethod
    def tearDownClass(cls):
        super(IntfTests, cls).tearDownClass()

    def test_lacp_show(self):
        self._url = self.reversed('lacp', self.__BOND)
        self._response = requests.get(self._url)
        self._response_json = json.loads(self._response.text)
        self.assertEquals(self._response.status_code, 200)
        self.assertGreater(len(self._response_json['output']), 1)

    def test_iplink_show(self):
        self._url = self.reversed('ipLink')
        self._response = requests.get(self._url)
        self._response_json = json.loads(self._response.text)
        self.assertEquals(self._response.status_code, 200)
        self.assertGreater(len(self._response_json['output']), 1)

    def test_ipaddr_add(self):
        self._url = self.reversed('ipLinkDev', self.__INTERFACE)
        address = '11.12.13.14'
        self._response = requests.post(self._url, data={
            'param': IpLink.PARAM_ADDRESS,
            'value': address
        })
        self.assertEquals(self._response.status_code, 200)
        output = requests.get(
            self.reversed('ipLinkDev', self.__INTERFACE)
        ).text
        self.assertIn(address, output)

    def test_iplink_set_mtu(self):
        self._url = self.reversed('ipLinkDev', self.__INTERFACE)
        mtu = 9005
        self._response = requests.post(self._url, data={
            'param': IpLink.PARAM_MTU,
            'value': mtu
        })
        output = requests.get(
            self.reversed('ipLinkDev', self.__INTERFACE)
        ).text
        self.assertIn('mtu %d' % mtu, output)

    def test_ifreload(self):
        self._url = self.reversed('ifState')
        mtu = 9005
        self._response = requests.post(
            self.reversed('ipLinkDev', self.__INTERFACE),
            data={
                'param': IpLink.PARAM_MTU,
                'value': mtu
            }
        )
        output = requests.get(
            self.reversed('ipLinkDev', self.__INTERFACE)
        ).text
        self.assertIn('mtu %d' % mtu, output)
        self._response = requests.post(self._url, data={
            'action': IfCommand.ACTION_RELOAD
        })
        self.assertEquals(self._response.status_code, 200)
        output = requests.get(
            self.reversed('ipLinkDev', self.__INTERFACE)
        ).text
        self.assertNotIn('mtu %d' % mtu, output)
